==> jc-1.4.0.tar.gz: org/w3c/dom/DOMException.h <==
// public class org.w3c.dom.DOMException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class ca80c12995054194 org_w3c_dom_DOMException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_org_w3c_dom_DOMException_H_
#define _JC_org_w3c_dom_DOMException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_w3c_dom_DOMException$sub_refs	_jc_org_w3c_dom_DOMException$sub_refs;
typedef struct _jc_org_w3c_dom_DOMException$sub_nonrefs	_jc_org_w3c_dom_DOMException$sub_nonrefs;
typedef struct _jc_org_w3c_dom_DOMException$refs	_jc_org_w3c_dom_DOMException$refs;
typedef struct _jc_org_w3c_dom_DOMException$nonrefs	_jc_org_w3c_dom_DOMException$nonrefs;
typedef struct _jc_org_w3c_dom_DOMException$object	_jc_org_w3c_dom_DOMException$object;

typedef struct _jc_org_w3c_dom_DOMException$fields_struct	_jc_org_w3c_dom_DOMException$fields_struct;
typedef const struct _jc_org_w3c_dom_DOMException$vmethods	_jc_org_w3c_dom_DOMException$vmethods;
typedef const struct _jc_org_w3c_dom_DOMException$vtable	_jc_org_w3c_dom_DOMException$vtable;
typedef const struct _jc_org_w3c_dom_DOMException$vtype	_jc_org_w3c_dom_DOMException$vtype;

// Class fields structure
struct _jc_org_w3c_dom_DOMException$fields_struct {
	jshort	DOMSTRING__5fSIZE__5fERR;
	jshort	HIERARCHY__5fREQUEST__5fERR;
	jshort	INDEX__5fSIZE__5fERR;
	jshort	INUSE__5fATTRIBUTE__5fERR;
	jshort	INVALID__5fACCESS__5fERR;
	jshort	INVALID__5fCHARACTER__5fERR;
	jshort	INVALID__5fMODIFICATION__5fERR;
	jshort	INVALID__5fSTATE__5fERR;
	jshort	NAMESPACE__5fERR;
	jshort	NOT__5fFOUND__5fERR;
	jshort	NOT__5fSUPPORTED__5fERR;
	jshort	NO__5fDATA__5fALLOWED__5fERR;
	jshort	NO__5fMODIFICATION__5fALLOWED__5fERR;
	jshort	SYNTAX__5fERR;
	jshort	TYPE__5fMISMATCH__5fERR;
	jshort	VALIDATION__5fERR;
	jshort	WRONG__5fDOCUMENT__5fERR;
};
extern _jc_org_w3c_dom_DOMException$fields_struct _jc_org_w3c_dom_DOMException$class_fields;

// Constructors
extern void _jc_org_w3c_dom_DOMException$method$_init$f5cdf9de5128930c(_jc_env *, struct _jc_org_w3c_dom_DOMException$object *, jshort, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_org_w3c_dom_DOMException$vmethods {
};

// Vtable
struct _jc_org_w3c_dom_DOMException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_org_w3c_dom_DOMException$vmethods	org_w3c_dom_DOMException;
};

// Vtype
struct _jc_org_w3c_dom_DOMException$vtype {
	_jc_type			type;
	_jc_org_w3c_dom_DOMException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_w3c_dom_DOMException$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_w3c_dom_DOMException$refs {
    _jc_org_w3c_dom_DOMException$sub_refs	org_w3c_dom_DOMException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_w3c_dom_DOMException$sub_nonrefs {
	jshort	code;
};

// Non-reference instance fields (object)
struct _jc_org_w3c_dom_DOMException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_org_w3c_dom_DOMException$sub_nonrefs	org_w3c_dom_DOMException;
};

// Object instance structure
struct _jc_org_w3c_dom_DOMException$object {
	_jc_org_w3c_dom_DOMException$refs	refs[0];
	_jc_word		lockword;
	_jc_org_w3c_dom_DOMException$vtype	*vtype;
	_jc_org_w3c_dom_DOMException$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_w3c_dom_DOMException$vtype _jc_org_w3c_dom_DOMException$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_w3c_dom_DOMException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_w3c_dom_DOMException$class_object;

#endif	/* _JC_org_w3c_dom_DOMException_H_ */

==> jc-1.4.6.tar.gz: org/w3c/dom/DOMException.h <==
// public class org.w3c.dom.DOMException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class ca80c12995054194 org_w3c_dom_DOMException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_org_w3c_dom_DOMException_H_
#define _JC_org_w3c_dom_DOMException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_w3c_dom_DOMException$sub_refs	_jc_org_w3c_dom_DOMException$sub_refs;
typedef struct _jc_org_w3c_dom_DOMException$sub_nonrefs	_jc_org_w3c_dom_DOMException$sub_nonrefs;
typedef struct _jc_org_w3c_dom_DOMException$refs	_jc_org_w3c_dom_DOMException$refs;
typedef struct _jc_org_w3c_dom_DOMException$nonrefs	_jc_org_w3c_dom_DOMException$nonrefs;
typedef struct _jc_org_w3c_dom_DOMException$object	_jc_org_w3c_dom_DOMException$object;

typedef struct _jc_org_w3c_dom_DOMException$fields_struct	_jc_org_w3c_dom_DOMException$fields_struct;
typedef const struct _jc_org_w3c_dom_DOMException$vmethods	_jc_org_w3c_dom_DOMException$vmethods;
typedef const struct _jc_org_w3c_dom_DOMException$vtable	_jc_org_w3c_dom_DOMException$vtable;
typedef const struct _jc_org_w3c_dom_DOMException$vtype	_jc_org_w3c_dom_DOMException$vtype;

// Class fields structure
struct _jc_org_w3c_dom_DOMException$fields_struct {
	jshort	DOMSTRING__5fSIZE__5fERR;
	jshort	HIERARCHY__5fREQUEST__5fERR;
	jshort	INDEX__5fSIZE__5fERR;
	jshort	INUSE__5fATTRIBUTE__5fERR;
	jshort	INVALID__5fACCESS__5fERR;
	jshort	INVALID__5fCHARACTER__5fERR;
	jshort	INVALID__5fMODIFICATION__5fERR;
	jshort	INVALID__5fSTATE__5fERR;
	jshort	NAMESPACE__5fERR;
	jshort	NOT__5fFOUND__5fERR;
	jshort	NOT__5fSUPPORTED__5fERR;
	jshort	NO__5fDATA__5fALLOWED__5fERR;
	jshort	NO__5fMODIFICATION__5fALLOWED__5fERR;
	jshort	SYNTAX__5fERR;
	jshort	TYPE__5fMISMATCH__5fERR;
	jshort	VALIDATION__5fERR;
	jshort	WRONG__5fDOCUMENT__5fERR;
};
extern _jc_org_w3c_dom_DOMException$fields_struct _jc_org_w3c_dom_DOMException$class_fields;

// Constructors
extern void _jc_org_w3c_dom_DOMException$method$_init$f5cdf9de5128930c(_jc_env *, struct _jc_org_w3c_dom_DOMException$object *, jshort, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_w3c_dom_DOMException$vmethods {
};

// Vtable
struct _jc_org_w3c_dom_DOMException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_org_w3c_dom_DOMException$vmethods	org_w3c_dom_DOMException;
};

// Vtype
struct _jc_org_w3c_dom_DOMException$vtype {
	_jc_type			type;
	_jc_org_w3c_dom_DOMException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_w3c_dom_DOMException$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_w3c_dom_DOMException$refs {
    _jc_org_w3c_dom_DOMException$sub_refs	org_w3c_dom_DOMException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_w3c_dom_DOMException$sub_nonrefs {
	jshort	code;
};

// Non-reference instance fields (object)
struct _jc_org_w3c_dom_DOMException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_org_w3c_dom_DOMException$sub_nonrefs	org_w3c_dom_DOMException;
};

// Object instance structure
struct _jc_org_w3c_dom_DOMException$object {
	_jc_org_w3c_dom_DOMException$refs	refs[0];
	_jc_word		lockword;
	_jc_org_w3c_dom_DOMException$vtype	*vtype;
	_jc_org_w3c_dom_DOMException$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_w3c_dom_DOMException$vtype _jc_org_w3c_dom_DOMException$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_w3c_dom_DOMException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_w3c_dom_DOMException$class_object;

#endif	/* _JC_org_w3c_dom_DOMException_H_ */
